library(car)
library(PMCMR)
library(laercio)
library(dplyr)
library(ggsignif)
library(ggplot2)
library(userfriendlyscience)

#---------------------------------------------------------------------
## compare the stiffness of the lizard teeth with the old and young cuticle
mod2<-read.csv("stiffness.csv")
#test normality --> fit normality
res.model2<-lm(mod2$stiffness ~ mod2$treatment)
res.model2$residuals
shapiro.test(res.model2$residuals)
qqnorm(res.model2$residuals)
#test equal variance --> violate the assumption
leveneTest(mod2$stiffness~mod2$treatment)
#Welch???s ANOVA 
oneway.test(stiffness ~ treatment, mod2,  var.equal = FALSE)
#One-way analysis of means (not assuming equal variances)
#data:  stiffness and treatment
#F = 76.198, num df = 2.000, denom df = 11.099, p-value = 3.288e-07
#posthocTGH
posthocTGH(mod2$stiffness, mod2$treatment, method=c("games-howell"), digits=4, conf.level = 0.95)
#       n  means variances
#hard   5  8.404    0.7506
#soft   5  4.317    0.2918
#teeth 12 28.807   79.8296
#             diff  ci.lo  ci.hi     t     df       p
#soft-hard  -4.087 -5.447 -2.728 8.952  6.702   .0001
#teeth-hard 20.403 13.402 27.403 7.823 11.486 < .0001
#teeth-soft 24.490 17.511 31.469 9.454 11.191 < .0001

#---------------------------------------------------------------------
###comparing the thickness of the cuticle between mature and teneral weevil
t<-read.csv("cuticle thickness.csv")
#subset the groups based on mature/teneral & epi&exo/endo
t.px<-subset(filter(t, place == "epi&exo"))
t.endo<-subset(filter(t, place == "endo"))
t.whole<-subset(filter(t, place == "whole"))
#comapring the thickness in whole cuticle:
#test normality & equal variance for (endo)-->violate normality--> Welch t-test 
res.t.whole<-lm(t.whole$thickness ~ t.whole$type)
shapiro.test(res.t.whole$residuals)
# Shapiro-Wilk normality test
# data:  res.t.whole$residuals
# W = 0.90074, p-value = 0.03076
leveneTest(t.whole$thickness~t.whole$type)
# Levene's Test for Homogeneity of Variance (center = median)
#       Df F value   Pr(>F)   
# group  1  10.937 0.003518 **
#        20               
t.test(thickness ~ type, data=t.whole)
# Welch Two Sample t-test
# data:  thickness by type
# t = 141.31, df = 10.465, p-value < 2.2e-16
# alternative hypothesis: true difference in means is not equal to 0
# 95 percent confidence interval:
#   179.1839 184.8903
# sample estimates:
#   mean in group mature mean in group teneral 
# 190.260455              8.223364 


#---------------------------------------------------------------------
##compare the angles of the orientation of the microfibres between successive layers in the mature and teneral cuticle
angle <- read.csv("angle measurement.csv")
x1<-c(62.94,57.6,63.89,79.41,82.94,56.89,79.53,56.99,34.59,38.03,71.97,58.9, 61.85,69.39,70.42,48.93,64.41,74.63,47.44)
x2 <-c(71.1, 83.47,39.75,39.09,41.82,51.92)
model<- lm(angle$angle~angle$type)
shapiro.test(model$residuals)
leveneTest(angle~type, data = angle)
t.test(x1,x2, var.equal=TRUE)
##fit normality and equal variance-> t-test
#Two Sample t-test
#data:  x1 and x2
#t = 1.107, df = 23, p-value = 0.2798
#alternative hypothesis: true difference in means is not equal to 0
#95 percent confidence interval:
#  -6.619695 21.859168
#sample estimates:
#  mean of x mean of y 
#        62.14474  54.52500 
